Lab library#

LIP6#

class gismap.lab_examples.lip6.Lip6Full(name=None, dbs=None, *, max_co_authors=9, min_title_words=2, taboo_words=None, taboo_authors=None)[source]#

Class for handling all LIP6 teams using https://www.lip6.fr/informations/annuaire.php to get team names.

class gismap.lab_examples.lip6.Lip6Map(name=None, dbs=None, *, max_co_authors=9, min_title_words=2, taboo_words=None, taboo_authors=None)[source]#

Class for handling a LIP6 team using https://www.lip6.fr/recherche/team_membres.php?acronyme=*team_acronym* as entry point. Default to NPA team.

Toulouse#

gismap.lab_examples.toulouse.LAAS_SERVICES = ['i2c', 'team', 'idea']#

LAAS support services exposed under /fr/services/ rather than /fr/equipes/.

gismap.lab_examples.toulouse.LAAS_TABOO = ['ditorial', 'Foreword', 'Brief Announcement', 'Preface', 'Préface', 'LAAS', 'CNRS', 'Comteam', 'Prospective', 'Bilan']#

Default editorials plus institutional words that pollute LAAS publication lists (annual reports, internal proceedings, etc.).

class gismap.lab_examples.toulouse.LaasFull(*args, with_support=True, department_level=True, **kwargs)[source]#

Class for handling all LAAS teams using https://www.laas.fr/fr/equipes/ to get team names.

Parameters:
  • with_support (bool, default=True) – If True, include the support services listed in LAAS_SERVICES in addition to the research teams.

  • department_level (bool, default=True) – Forwarded to LaasMap for each team. If True, authors are grouped by department rather than by team.

  • **kwargs – Forwarded to LabMap. As in LaasMap, max_co_authors=50 and taboo_words=LAAS_TABOO are the defaults.

class gismap.lab_examples.toulouse.LaasMap(*args, department_level=False, **kwargs)[source]#

Class for handling a LAAS team from its name. Defaults to the sara team.

Parameters:
  • name (str, default=”sara”) – Team or service identifier as used in the LAAS website URLs.

  • department_level (bool, default=False) – If True, label authors by their parent department (e.g. RISC) rather than by their team name. Service members are labelled “Support”.

  • **kwargs – Forwarded to LabMap. The LAAS-tuned defaults max_co_authors=50 and taboo_words=LAAS_TABOO are applied unless overridden by the caller.

class gismap.lab_examples.toulouse.SolaceMap(name=None, dbs=None, *, max_co_authors=9, min_title_words=2, taboo_words=None, taboo_authors=None)[source]#

Class for handling the Solace team (https://solace.cnrs.fr).

Algotel-Cores#

class gismap.lab_examples.cotel.AlgoRes2016(name=None, dbs=None, *, max_co_authors=9, min_title_words=2, taboo_words=None, taboo_authors=None)[source]#

https://algotel2016.labri.fr/index.php?committee https://algotel2016.labri.fr/index.php?cores

class gismap.lab_examples.cotel.AlgoRes2017(name=None, dbs=None, *, max_co_authors=9, min_title_words=2, taboo_words=None, taboo_authors=None)[source]#

https://web.archive.org/web/20170719001105/http://algotel2017.ensai.fr/ https://web.archive.org/web/20171203000444/http://cores2017.ensai.fr/

class gismap.lab_examples.cotel.AlgoRes2018(name=None, dbs=None, *, max_co_authors=9, min_title_words=2, taboo_words=None, taboo_authors=None)[source]#

https://algotel2018.complexnetworks.fr/comite.html http://cores2018.complexnetworks.fr/comite.html

class gismap.lab_examples.cotel.AlgoRes2019(name=None, dbs=None, *, max_co_authors=9, min_title_words=2, taboo_words=None, taboo_authors=None)[source]#

https://www.irit.fr/algotel2019/ https://www.irit.fr/cores2019/index.html

class gismap.lab_examples.cotel.AlgoRes2020(name=None, dbs=None, *, max_co_authors=9, min_title_words=2, taboo_words=None, taboo_authors=None)[source]#

https://cores-algotel-2020.imag.fr/

class gismap.lab_examples.cotel.AlgoRes2021(name=None, dbs=None, *, max_co_authors=9, min_title_words=2, taboo_words=None, taboo_authors=None)[source]#

https://apps.univ-lr.fr/cgi-bin/WebObjects/Colloque.woa/wa/menu?code=2721&idMenu=10922

class gismap.lab_examples.cotel.AlgoRes2022(name=None, dbs=None, *, max_co_authors=9, min_title_words=2, taboo_words=None, taboo_authors=None)[source]#

https://sites.google.com/view/algotel-cores-2022

class gismap.lab_examples.cotel.AlgoRes2023(name=None, dbs=None, *, max_co_authors=9, min_title_words=2, taboo_words=None, taboo_authors=None)[source]#

https://coresalgotel2023.i3s.univ-cotedazur.fr

class gismap.lab_examples.cotel.AlgoRes2024(name=None, dbs=None, *, max_co_authors=9, min_title_words=2, taboo_words=None, taboo_authors=None)[source]#

https://algotelcores2024.sciencesconf.org

class gismap.lab_examples.cotel.AlgoRes2025(name=None, dbs=None, *, max_co_authors=9, min_title_words=2, taboo_words=None, taboo_authors=None)[source]#

https://algotel-cores25.sciencesconf.org/

class gismap.lab_examples.cotel.AlgoRes2026(name=None, dbs=None, *, max_co_authors=9, min_title_words=2, taboo_words=None, taboo_authors=None)[source]#

https://algotel-cores26.sciencesconf.org/

class gismap.lab_examples.cotel.CoTel(name=None, dbs=None, *, max_co_authors=9, min_title_words=2, taboo_words=None, taboo_authors=None)[source]#

Abstract class for Algotel/Cores PC committee maps.

Cf https://algotel.eu.org/

gismap.lab_examples.cotel.strip_li(li)[source]#
Parameters:

li (Tag) – HTML list item

Returns:

Searcher name

Return type:

str

Cedric#

class gismap.lab_examples.cedric.CedricFull(name=None, dbs=None, *, max_co_authors=9, min_title_words=2, taboo_words=None, taboo_authors=None)[source]#

Class for handling all CNAM Cedric teams using https://cedric.cnam.fr/equipes to get team names.

class gismap.lab_examples.cedric.CedricMap(name=None, dbs=None, *, max_co_authors=9, min_title_words=2, taboo_words=None, taboo_authors=None)[source]#

Class for handling a CNAM Cedric team from its name. Default to roc team.

LAMSADE#

class gismap.lab_examples.lamsade.Lamsade(name=None, dbs=None, *, max_co_authors=9, min_title_words=2, taboo_words=None, taboo_authors=None)[source]#

Class for handling the Lamsade team (Dauphine). The data is retrieved from the webpage of the team, and parsed with BeautifulSoup. The name, image url and webpage of each researcher are extracted and stored in a LabAuthor object.

gismap.lab_examples.lamsade.lamsade_parse(div)[source]#
Parameters:

div (BeautifulSoup) – Soup of the div of one researcher

Returns:

name, image url (or None), webpage (or None)

Return type:

tuple

LINCS#

class gismap.lab_examples.lincs.LINCS(name=None, dbs=None, *, max_co_authors=9, min_title_words=2, taboo_words=None, taboo_authors=None)[source]#

IRIF#

class gismap.lab_examples.irif.IrifFull(name=None, dbs=None, *, max_co_authors=9, min_title_words=2, taboo_words=None, taboo_authors=None)[source]#

Class for handling all IRIF teams.

class gismap.lab_examples.irif.IrifMap(name=None, dbs=None, *, max_co_authors=9, min_title_words=2, taboo_words=None, taboo_authors=None)[source]#

Class for handling an IRIF team using https://www.irif.fr/equipes/*team_acronym*/index as entry point. Default to graphes team.