Lab library#
LIP6#
Toulouse#
- class gismap.lab_examples.toulouse.LaasFull(name=None, dbs=None)[source]#
Class for handling all LAAS teams using https://www.laas.fr/fr/equipes/ to get team names.
Algotel-Cores#
- class gismap.lab_examples.cotel.AlgoRes2016(name=None, dbs=None)[source]#
https://algotel2016.labri.fr/index.php?committee https://algotel2016.labri.fr/index.php?cores
- class gismap.lab_examples.cotel.AlgoRes2017(name=None, dbs=None)[source]#
https://web.archive.org/web/20170719001105/http://algotel2017.ensai.fr/ https://web.archive.org/web/20171203000444/http://cores2017.ensai.fr/
- class gismap.lab_examples.cotel.AlgoRes2018(name=None, dbs=None)[source]#
https://algotel2018.complexnetworks.fr/comite.html http://cores2018.complexnetworks.fr/comite.html
- class gismap.lab_examples.cotel.AlgoRes2019(name=None, dbs=None)[source]#
https://www.irit.fr/algotel2019/ https://www.irit.fr/cores2019/index.html
- class gismap.lab_examples.cotel.AlgoRes2021(name=None, dbs=None)[source]#
https://apps.univ-lr.fr/cgi-bin/WebObjects/Colloque.woa/wa/menu?code=2721&idMenu=10922
Cedric#
LAMSADE#
- class gismap.lab_examples.lamsade.Lamsade(name=None, dbs=None)[source]#
Class for handling the Lamsade team (Dauphine). The data is retrieved from the webpage of the team, and parsed with BeautifulSoup. The name, image url and webpage of each researcher are extracted and stored in a LabAuthor object.